@@ -8,7 +8,7 @@ import torch
 
 class Data_Organizer(object):
     # Resampling 후 저장 추가해야 됨.
-    def __init__(self, SAVE_PATH, ID = 'ingradient', resampling = None, normalizer = None, mode = 'train', do_set_direction = True):
+    def __init__(self, SAVE_PATH, ID = 'ingradient', resampling = None, normalizer = None, mode = 'train', do_set_direction = False):
         self.crop = Cropping()
         self.SAVE_PATH = SAVE_PATH
         self.ID = ID
@@ -55,7 +55,7 @@ class Data_Organizer(object):
                 images = np.vstack(images, img)
         
 
-        print("current path : ", seg_path, "image shapes :", images.shape, "seg shapes :", seg.shape)
+        print("current path : ", seg_path, "image shapes :", images.shape, "seg shapes :", seg.shape, "spacing :", save_dict['spacing'])
         img_arr, seg_arr = self.crop(images, seg)
 
         if self.do_set_direction:
@@ -72,25 +72,25 @@ class Data_Organizer(object):
 
         if self.resampling != None:
             if isinstance(img_arr, np.ndarray):
-                x = torch.tensor(img_arr.copy())
+                img_arr = torch.tensor(img_arr.copy())
             else:
-                x = img_arr
+                img_arr = img_arr
             
             if isinstance(seg_arr, np.ndarray):
-                y = torch.tensor(seg_arr.copy())
+                seg_arr = torch.tensor(seg_arr.copy())
             
             else:
-                y = seg_arr
+                seg_arr = seg_arr
 
             if self.mode == 'train' :
-                result = self.resampling(torch.vstack((x, y.unsqueeze(0))), save_dict)
-                x = result[:-1]
-                y = result[-1].squeeze(0)
+                result = self.resampling(torch.vstack((img_arr, seg_arr.unsqueeze(0))), save_dict)
+                img_arr = result[:-1]
+                seg_arr = result[-1].squeeze(0)
             
             else:
-                x = self.resampling(x, save_dict)
+                img_arr = self.resampling(img_arr, save_dict)
         
-        if isinstance(x, np.ndarray):
+        if isinstance(img_arr, np.ndarray):
             np.savez(os.path.join(self.SAVE_PATH, self.ID+str(index)+'.npz'), x =img_arr, y=seg_arr)
         
         else:
