@@ -365,8 +365,10 @@ class DataLoader3D(object):
             for i in range(len(odd_pad)):
                 even_pad[i*2] += odd_pad[i]
             even_pad = tuple(even_pad[::-1].astype(int).copy())
+            print("even_pad")
             images = F.pad(images, even_pad, "constant", 0 )
             seg = F.pad(seg, even_pad, "constant", 0 )
+            print("images shape", images.shape, "seg shape", seg.shape)
 
         return images, seg, info
 
